﻿-- 1、创建数据库
----------------------------------------------------------------------------------------------------
CREATE DATABASE MicroEDU;
GO
USE MicroEDU;
GO


-- 2、创建数据表
----------------------------------------------------------------------------------------------------
CREATE TABLE T_Districts(Id INT,ParentId INT,Level INT,Name VARCHAR(30),Code VARCHAR(12));
CREATE TABLE T_Courses(Id INT IDENTITY PRIMARY KEY,Name VARCHAR(30) NOT NULL);
CREATE TABLE T_Classes(Id INT IDENTITY PRIMARY KEY,Name VARCHAR(30) NOT NULL);
GO
CREATE TABLE T_Students(
    Id INT IDENTITY PRIMARY KEY,
    ClassId INT,
    Code VARCHAR(30),
    Name VARCHAR(30) NOT NULL,
    Gender INT,
    Birthday DATETIME,
    Remark VARCHAR(1000)
);
GO
CREATE TABLE T_ExamResults(
    Id INT IDENTITY PRIMARY KEY,
    Counts INT,
    CourseId INT,
    StudentId INT,
    Scores DECIMAL(4,1)
);
GO


-- 3、补充对表和字段的注释
----------------------------------------------------------------------------------------------------
-- Level 1 省、自治区、直辖市
-- Level 2 地级市、自治州、盟
-- Level 3 市辖区、县、县级市
EXEC sp_addextendedproperty N'MS_Description','地区表',N'SCHEMA',N'DBO',N'TABLE',T_Districts,NULL,NULL;
EXEC sp_addextendedproperty N'MS_Description','主键',N'SCHEMA',N'DBO',N'TABLE',T_Districts,N'COLUMN',Id;
EXEC sp_addextendedproperty N'MS_Description','父ID',N'SCHEMA',N'DBO',N'TABLE',T_Districts,N'COLUMN',ParentId;
EXEC sp_addextendedproperty N'MS_Description','等级{1省/2市/3县}',N'SCHEMA',N'DBO',N'TABLE',T_Districts,N'COLUMN',Level;
EXEC sp_addextendedproperty N'MS_Description','名称',N'SCHEMA',N'DBO',N'TABLE',T_Districts,N'COLUMN',Name;
EXEC sp_addextendedproperty N'MS_Description','编码',N'SCHEMA',N'DBO',N'TABLE',T_Districts,N'COLUMN',Code;
GO
EXEC sp_addextendedproperty N'MS_Description','课程表',N'SCHEMA',N'DBO',N'TABLE',T_Courses,NULL,NULL;
EXEC sp_addextendedproperty N'MS_Description','主键',N'SCHEMA',N'DBO',N'TABLE',T_Courses,N'COLUMN',Id;
EXEC sp_addextendedproperty N'MS_Description','名称',N'SCHEMA',N'DBO',N'TABLE',T_Courses,N'COLUMN',Name;
GO
EXEC sp_addextendedproperty N'MS_Description','班级表',N'SCHEMA',N'DBO',N'TABLE',T_Classes,NULL,NULL;
EXEC sp_addextendedproperty N'MS_Description','主键',N'SCHEMA',N'DBO',N'TABLE',T_Classes,N'COLUMN',Id;
EXEC sp_addextendedproperty N'MS_Description','名称',N'SCHEMA',N'DBO',N'TABLE',T_Classes,N'COLUMN',Name;
GO
EXEC sp_addextendedproperty N'MS_Description','学生表',N'SCHEMA',N'DBO',N'TABLE',T_Students,NULL,NULL;
EXEC sp_addextendedproperty N'MS_Description','主键',N'SCHEMA',N'DBO',N'TABLE',T_Students,N'COLUMN',Id;
EXEC sp_addextendedproperty N'MS_Description','班级ID',N'SCHEMA',N'DBO',N'TABLE',T_Students,N'COLUMN',ClassId;
EXEC sp_addextendedproperty N'MS_Description','学号',N'SCHEMA',N'DBO',N'TABLE',T_Students,N'COLUMN',Code;
EXEC sp_addextendedproperty N'MS_Description','名称',N'SCHEMA',N'DBO',N'TABLE',T_Students,N'COLUMN',Name;
EXEC sp_addextendedproperty N'MS_Description','性别',N'SCHEMA',N'DBO',N'TABLE',T_Students,N'COLUMN',Gender;
EXEC sp_addextendedproperty N'MS_Description','出生日期',N'SCHEMA',N'DBO',N'TABLE',T_Students,N'COLUMN',Birthday;
EXEC sp_addextendedproperty N'MS_Description','备注',N'SCHEMA',N'DBO',N'TABLE',T_Students,N'COLUMN',Remark;
GO
EXEC sp_addextendedproperty N'MS_Description','成绩表',N'SCHEMA',N'DBO',N'TABLE',T_ExamResults,NULL,NULL;
EXEC sp_addextendedproperty N'MS_Description','主键',N'SCHEMA',N'DBO',N'TABLE',T_ExamResults,N'COLUMN',Id;
EXEC sp_addextendedproperty N'MS_Description','次数',N'SCHEMA',N'DBO',N'TABLE',T_ExamResults,N'COLUMN',Name;
EXEC sp_addextendedproperty N'MS_Description','课程ID',N'SCHEMA',N'DBO',N'TABLE',T_ExamResults,N'COLUMN',CourseId;
EXEC sp_addextendedproperty N'MS_Description','学生ID',N'SCHEMA',N'DBO',N'TABLE',T_ExamResults,N'COLUMN',StudentId;
EXEC sp_addextendedproperty N'MS_Description','分数',N'SCHEMA',N'DBO',N'TABLE',T_ExamResults,N'COLUMN',Scores;
GO


-- 4、向表中插入数据
----------------------------------------------------------------------------------------------------
INSERT INTO MicroEDU..T_Districts 
VALUES(100001,NULL,1,'上海市','310000'),
      (100002,NULL,1,'江苏省','320000'),
      (100003,NULL,1,'浙江省','330000'),
      (100004,100003,2,'杭州市','330100'),
      (100005,100003,2,'宁波市','330200'),
      (100006,100003,2,'温州市','330300'),
      (100007,100003,2,'嘉兴市','330400'),
      (100008,100003,2,'湖州市','330500'),
      (100009,100003,2,'绍兴市','330600'),
      (100010,100004,3,'上城区','330102'),
      (100011,100004,3,'下城区','330103'),
      (100012,100004,3,'江干区','330104'),
      (100013,100004,3,'拱墅区','330105'),
      (100014,100004,3,'西湖区','330106'),
      (100015,100004,3,'滨江区','330108'),
      (100016,100004,3,'萧山区','330109'),
      (100017,100004,3,'余杭区','330110'),
      (100018,100004,3,'富阳区','330111'),
      (100019,100004,3,'临安区','330112');
GO
INSERT INTO MicroEDU..T_Courses VALUES('语文'),('数学'),('英语');
INSERT INTO MicroEDU..T_Classes VALUES('三(1)班'),('三(2)班'),('三(3)班');
GO
INSERT INTO MicroEDU..T_Students 
VALUES(1,'S330102001','郑强',1,'1999-12-18',NULL),
      (1,'S330102002','肖俊生',1,'1998-11-11',NULL),
      (1,'S330102003','刘冰洁',0,'1999-12-28',NULL),
      (1,'S330103004','李梦丽',0,'2000-02-08',NULL),
      (1,'S330103005','李鹏飞',1,'2001-01-10',NULL),
      (1,'S330103006','刘璐',0,'2000-01-20',NULL),
      (1,'S330300007','钱波',1,'2000-04-16',NULL),
      (1,'S330104008','张娟',0,'1999-12-01',NULL),
      (1,'S330104009','金桥',1,'1999-12-12',NULL),
      (1,'S330104010','高雅雪',0,'2000-10-10',NULL),
      (1,'S330105011','马晓芸',0,'2003-01-18',NULL),
      (1,'S330105012','张美丽',0,'2000-03-11',NULL),
      (2,'S330105001','李方圆',1,'1998-12-02',NULL),
      (2,'S330106002','郭小妹',1,'2002-01-01',NULL),
      (2,'S330106003','宋阳',1,'2000-01-13',NULL),
      (2,'S330106004','韩子龙',1,'2001-01-22',NULL),
      (2,'S330106005','黄超',1,'1999-10-03',NULL),
      (2,'S330106006','黄娟',0,'2001-05-02',NULL),
      (2,'S330106007','刘艳',0,'1999-12-30',NULL),
      (2,'S330106008','王晓芳',0,'2000-04-10',NULL),
      (2,'S330106009','宋梅',0,'1998-12-27',NULL),
      (3,'S330106001','刘月月',0,'2001-01-09',NULL),
      (3,'S330200002','李花花',0,'2000-05-14',NULL),
      (3,'S330200003','张晓莉',0,'2002-06-01',NULL),
      (3,'S330200004','徐妹',0,'2000-02-07',NULL),
      (3,'S330200005','马鹏飞',1,'1997-03-25',NULL),
      (3,'S330108006','张家兴',1,'2000-03-12',NULL),
      (3,'S330108007','宋斌',1,'2000-03-16',NULL),
      (3,'S330400008','朱青青',0,'2001-02-11',NULL),
      (3,'S330400009','杨菲菲',0,'2003-01-07',NULL);
GO
DECLARE @i INT,@j INT,@k INT
DECLARE @score DECIMAL(4,1)
SET @i=1
SET @j=1
SET @k=1
WHILE @i<=10 -- 共统考了 10 次
BEGIN
    WHILE @j<=3 -- 共 3 个班级
    BEGIN
        WHILE @k<=30 -- 共 30 个学生
        BEGIN
            SET @score=ROUND(RAND()*100,0);      -- 计算一个 [0,100] 的随机分数
            IF @score<50 SET @score=100-@score;  -- 为避免低分过多，取一下补数
            IF RAND()<0.1 SET @score=@score-0.5; -- 制造少量(约10%)带 0.5 的分数
            INSERT INTO MicroEDU..T_ExamResults VALUES(@i,@j,@k,@score);
            SET @k=@k+1;
        END
        SET @k=1
        SET @j=@j+1
    END
    SET @j=1
    SET @i=@i+1
END;
GO


-- 5、后续博文补充创建的数据库对象
----------------------------------------------------------------------------------------------------
-- 《SQL Server温故系列(1)：数据操作 CRUD 之增删改合》
CREATE TABLE T_GoodStudents(Id INT,Name VARCHAR(30),Gender INT,Birthday DATETIME);
-- 《SQL Server温故系列(3)：高级查询之子查询 & CTE》
CREATE TABLE T_Persons(Id INT,Name VARCHAR(30),Father INT,Mother INT);
INSERT INTO MicroEDU..T_Persons 
VALUES(1,'卢光升',NULL,NULL),
      (2,'王迎雪',NULL,NULL),
      (3,'卢启明',1,2),
      (4,'卢启天',1,2),
      (5,'李丽华',NULL,NULL),
      (6,'刘佳丽',NULL,NULL),
      (7,'卢宗仁',3,5),
      (8,'卢宗义',4,6),
      (9,'王香梅',NULL,NULL),
      (10,'卢小妹',7,9);
-- 


----------------------------------------------------------------------------------------------------
--DROP DATABASE MicroEDU;
--TRUNCATE TABLE MicroEDU..T_Districts;
--TRUNCATE TABLE MicroEDU..T_Courses;
--TRUNCATE TABLE MicroEDU..T_Classes;
--TRUNCATE TABLE MicroEDU..T_Students;
--TRUNCATE TABLE MicroEDU..T_ExamResults;
----------------------------------------------------------------------------------------------------
/*
1 所有老师的实例用学生代替
2 运算符前后加空格
3 直接用数字表述课程，不必非得匹配课程表（直观易理解）
4 如果要换行，就每个关键字一行，不要觉得某一行太短就不换，除非是有内联关系的子查询
*/
